aboutsummaryrefslogtreecommitdiff
path: root/libstdc++-v3/testsuite/22_locale/collate/hash/char/2.cc
diff options
context:
space:
mode:
Diffstat (limited to 'libstdc++-v3/testsuite/22_locale/collate/hash/char/2.cc')
-rw-r--r--libstdc++-v3/testsuite/22_locale/collate/hash/char/2.cc14
1 files changed, 7 insertions, 7 deletions
diff --git a/libstdc++-v3/testsuite/22_locale/collate/hash/char/2.cc b/libstdc++-v3/testsuite/22_locale/collate/hash/char/2.cc
index b4fabd4de14..91b25044bc4 100644
--- a/libstdc++-v3/testsuite/22_locale/collate/hash/char/2.cc
+++ b/libstdc++-v3/testsuite/22_locale/collate/hash/char/2.cc
@@ -1,6 +1,6 @@
-// { dg-require-namedlocale "en_US" }
-// { dg-require-namedlocale "fr_FR" }
-// { dg-require-namedlocale "de_DE" }
+// { dg-require-namedlocale "en_US.ISO8859-1" }
+// { dg-require-namedlocale "fr_FR.ISO8859-15" }
+// { dg-require-namedlocale "de_DE.ISO8859-15" }
// 2001-08-15 Benjamin Kosnik <bkoz@redhat.com>
@@ -26,7 +26,7 @@
#include <locale>
#include <testsuite_hooks.h>
// Check German "de_DE" locale.
void test02()
{
using namespace std;
@@ -36,9 +36,9 @@ void test02()
// basic construction
locale loc_c = locale::classic();
- locale loc_us = locale("en_US");
- locale loc_fr = locale("fr_FR");
- locale loc_de = locale("de_DE");
+ locale loc_us = locale(ISO_8859(1,en_US));
+ locale loc_fr = locale(ISO_8859(15,fr_FR));
+ locale loc_de = locale(ISO_8859(15,de_DE));
VERIFY( loc_c != loc_de );
VERIFY( loc_us != loc_fr );
VERIFY( loc_us != loc_de );
@@ -26,7 +26,7 @@
#include <locale>
#include <testsuite_hooks.h>
-// Check German "de_DE" locale.
+// Check German "de_DE.ISO8859-15" locale.
void test02()
{